#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-action
version:              0.2.6
visibility:           public
id:                   lens-action-0.2.6-GH5wWrXelGa9jYmInNUwWa
key:                  lens-action-0.2.6-GH5wWrXelGa9jYmInNUwWa
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens-action/
synopsis:             Monadic Getters and Folds
description:
    This package contains combinators and types for working with
    monadic getters and folds as split off from the original
    lens package.

category:             Data, Lenses, Generics
abi:                  7f19510a7c55ef4bdd2755c0a85b42ed
exposed:              True
exposed-modules:
    Control.Lens.Action Control.Lens.Action.Internal
    Control.Lens.Action.Reified Control.Lens.Action.Type

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lens-action-0.2.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lens-action-0.2.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lens-action-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-action
hs-libraries:         HSlens-action-0.2.6-GH5wWrXelGa9jYmInNUwWa
depends:
    base-4.18.2.1 comonad-5.0.10-318hdfRIpcaGiaaWwzNpPU
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    lens-5.3.4-kk6OqUq8ZY4lLpzN7435U mtl-2.3.1
    profunctors-5.6.3-L7AmH2PuyYLAtp7ecLVlPy
    semigroupoids-6.0.2-7aluKECiAjj3pr6vbSNpxs transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-lens-action/html/lens-action.haddock
haddock-html:         /usr/share/doc/haskell-lens-action/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

